==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/id-ID/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Konfirmasi Penghapusan Aset dalam Jumlah Besar',
    'bulk_restore'      => 'Konfirmasi Pemulihan Aset Secara Massal', 
  'bulk_delete_help'	=> 'Meninjau aset untuk penghapusan massal di bawah ini. Setelah dihapus, aset-aset ini dapat dipulihkan, tetapi mereka tidak lagi akan dikaitkan dengan setiap pengguna yang mereka saat ini digunakan.',
  'bulk_restore_help'	=> 'Tinjau aset untuk pemulihan massal di bawah. Setelah dipulihkan, aset ini tidak akan dikaitkan dengan pengguna mana pun yang sebelumnya ditetapkan untuknya.',
  'bulk_delete_warn'	=> 'Anda akan menghapus :asset_count aset.',
  'bulk_restore_warn'	=> 'Anda akan memulihkan :asset_count aset.',
    'bulk_update'		=> 'Perbarui aset jumlah besar',
    'bulk_update_help'	=> 'Formulir ini mengizinkan anda untuk memperbarui kelipatan aset dalam sekali proses. Cukup isi di field yang hendak di rubah. Jika ada yang kosong tidak akan dirubah. ',
    'bulk_update_warn'	=> 'Anda akan mengedit properti dari satu aset.|Anda akan mengedit properti dari :asset_count aset.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'Diberikan kepada',
    'checkout_date'		=> 'Tanggal Pemberian',
    'checkin_date'		=> 'Tanggal Pengembalian',
    'checkout_to'		=> 'Diberikan kepada',
    'cost'				=> 'Harga Pembelian',
    'create'			=> 'Membuat aset',
    'date'				=> 'Tanggal pembelian',
    'depreciation'	    => 'Penyusutan',
    'depreciates_on'	=> 'Penyusutan aktif',
    'default_location'	=> 'Lokasi awal',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'Tanggal EOL',
    'eol_rate'			=> 'Tingkat EOL',
    'expected_checkin'  => 'Tanggal pengembalian diharapkan diterima',
    'expires'			=> 'Kadaluarsa',
    'fully_depreciated'	=> 'Penyusutan penuh',
    'help_checkout'		=> 'Jika anda ingin segera menggunakan aset ini segera, pilih "Ready to Deploy" dari daftar status di atas. ',
    'mac_address'		=> 'Alamat MAC',
    'manufacturer'		=> 'Produsen',
    'model'				=> 'Model',
    'months'			=> 'bulan',
    'name'				=> 'Nama Aset',
    'notes'				=> 'Catatan',
    'order'				=> 'Nomor Pemesanan',
    'qr'				=> 'Kode QR',
    'requestable'		=> 'Pengguna dapat meminta aset ini',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Memilih Tipe Status',
    'serial'			=> 'Serial',
    'status'			=> 'Status',
    'tag'				=> 'Tag Aset',
    'update'			=> 'Perbarui Aset',
    'warranty'			=> 'Garansi',
        'warranty_expires'		=> 'Garansi Berakhir',
    'years'				=> 'tahun',
    'asset_location' => 'Perbarui Lokasi Aset',
    'asset_location_update_default_current' => 'Perbarui lokasi default DAN lokasi sebenarnya',
    'asset_location_update_default' => 'Perbarui hanya lokasi default',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'Status aset tersebut tidak dapat ditetapkan. Aset ini tidak dapat digunakan.',
    'asset_deployable' => 'Status aset dapat ditetapkan. Aset ini dapat digunakan.',
    'processing_spinner' => 'Memproses... (Mungkin memerlukan sedikit waktu untuk file besar)',
    'optional_infos'  => 'Informasi Tambahan',
    'order_details'   => 'Informasi Pesanan'
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/id-ID/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Konfirmasi Penghapusan Aset dalam Jumlah Besar',
    'bulk_restore'      => 'Konfirmasi Pemulihan Aset Secara Massal', 
  'bulk_delete_help'	=> 'Meninjau aset untuk penghapusan massal di bawah ini. Setelah dihapus, aset-aset ini dapat dipulihkan, tetapi mereka tidak lagi akan dikaitkan dengan setiap pengguna yang mereka saat ini digunakan.',
  'bulk_restore_help'	=> 'Tinjau aset untuk pemulihan massal di bawah. Setelah dipulihkan, aset ini tidak akan dikaitkan dengan pengguna mana pun yang sebelumnya ditetapkan untuknya.',
  'bulk_delete_warn'	=> 'Anda akan menghapus :asset_count aset.',
  'bulk_restore_warn'	=> 'Anda akan memulihkan :asset_count aset.',
    'bulk_update'		=> 'Perbarui aset jumlah besar',
    'bulk_update_help'	=> 'Formulir ini mengizinkan anda untuk memperbarui kelipatan aset dalam sekali proses. Cukup isi di field yang hendak di rubah. Jika ada yang kosong tidak akan dirubah. ',
    'bulk_update_warn'	=> 'Anda akan mengedit properti dari satu aset.|Anda akan mengedit properti dari :asset_count aset.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'Diberikan kepada',
    'checkout_date'		=> 'Tanggal Pemberian',
    'checkin_date'		=> 'Tanggal Pengembalian',
    'checkout_to'		=> 'Diberikan kepada',
    'cost'				=> 'Harga Pembelian',
    'create'			=> 'Membuat aset',
    'date'				=> 'Tanggal pembelian',
    'depreciation'	    => 'Penyusutan',
    'depreciates_on'	=> 'Penyusutan aktif',
    'default_location'	=> 'Lokasi awal',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'Tanggal EOL',
    'eol_rate'			=> 'Tingkat EOL',
    'expected_checkin'  => 'Tanggal pengembalian diharapkan diterima',
    'expires'			=> 'Kadaluarsa',
    'fully_depreciated'	=> 'Penyusutan penuh',
    'help_checkout'		=> 'Jika anda ingin segera menggunakan aset ini segera, pilih "Ready to Deploy" dari daftar status di atas. ',
    'mac_address'		=> 'Alamat MAC',
    'manufacturer'		=> 'Produsen',
    'model'				=> 'Model',
    'months'			=> 'bulan',
    'name'				=> 'Nama Aset',
    'notes'				=> 'Catatan',
    'order'				=> 'Nomor Pemesanan',
    'qr'				=> 'Kode QR',
    'requestable'		=> 'Pengguna dapat meminta aset ini',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Memilih Tipe Status',
    'serial'			=> 'Serial',
    'status'			=> 'Status',
    'tag'				=> 'Tag Aset',
    'update'			=> 'Perbarui Aset',
    'warranty'			=> 'Garansi',
        'warranty_expires'		=> 'Garansi Berakhir',
    'years'				=> 'tahun',
    'asset_location' => 'Perbarui Lokasi Aset',
    'asset_location_update_default_current' => 'Perbarui lokasi default DAN lokasi sebenarnya',
    'asset_location_update_default' => 'Perbarui hanya lokasi default',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'Status aset tersebut tidak dapat ditetapkan. Aset ini tidak dapat digunakan.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'Status aset dapat ditetapkan. Aset ini dapat digunakan.',
    'processing_spinner' => 'Memproses... (Mungkin memerlukan sedikit waktu untuk file besar)',
    'optional_infos'  => 'Informasi Tambahan',
    'order_details'   => 'Informasi Pesanan'
];
